#[non_exhaustive]pub enum CacheError {
ManifestNotFound {
id: String,
},
ObjectNotFound {
checksum: String,
},
Integrity {
expected: String,
actual: String,
},
Parse(ParseError),
Io(Error),
}Expand description
Errors the cache integrity machinery can surface.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ManifestNotFound
The manifest for the requested snapshot id was not present in the cache.
Mirrors the oracle’s “Manifest not found locally. Did you forget to
fetch …?” failure in _snapdir_check_integrity.
ObjectNotFound
A file object referenced by the manifest was missing from the cache.
Integrity
A cached object’s bytes did not hash to the address it is filed under — the object is corrupt or tampered.
Fields
Parse(ParseError)
A manifest’s text could not be parsed.
Io(Error)
An underlying filesystem failure.